
rm(list=ls()) # Clears the list of objects in memory


### SOME DATA ----------------
set.seed(42)
data<-rnorm(n=20,mean=10,sd=2)
###---------------------------



### DEFAULT PLOT ---
plot(data)
###-----------------


###########################################
###                                     ###
###   ###   ##### #   # #  ###  #####   ###
###   #  #  #     #   # # #   # #       ###
###   #   # ###   #   # # #     ###     ###
###   #  #  #      # #  # #   # #       ###
###   ###   #####   #   #  ###  #####   ###
###                                     ###
###########################################



### CREATE A GRAPHIC DEVICE ------------------------------------
windows() # creates a graphic device with the default parameters
windows(width=4,height=6,title="My graph") # With some parameters
###-------------------------------------------------------------

###########################################
###                                     ###
###   ##### #  ###  #   # ####  #####   ###
###   #     # #     #   # #   # #       ###
###   ###   # #  ## #   # ####  ###     ###
###   #     # #   # #   # #  #  #       ###
###   #     #  ###   ###  #   # #####   ###
###                                     ###
###########################################


### SOME PARAMETERS FOR THE FIGURE -------------------------------------------------
?par() # lots of available parameters
plot(data) # plot with default pararmeters

# parameter mfrow=c(rows,columns) ..................................... see layout()
windows(width=4,height=6,title="My graph")
par(mfrow=c(2,1))
plot(data)
plot(data)

box(which="figure") # we can see that some space is left for a title...

# parameter fig=c(x1,x2,y1,y2) in NDC .........................................
windows(width=7,height=6,title="My graph")
par(fig=c(0,0.5,0.4,1)) # <--- set the parameters for the first plot
plot(data)
box(which="figure")

par(fig=c(0.5,1,0.5,1),new=T) # <--- update the parameters for a second plot
plot(data)
box(which="figure")

par(fig=c(0,0.25,0,0.4),new=T) # <--- update the parameters for a third plot
plot(data)
box(which="figure")

par(fig=c(0.25,1,0,0.5),new=T) # <--- update the parameters for a fourth plot
plot(data)
box(which="figure") # Shows that the last figure is overlaid ...................

# Overlaying figures with fig ...........
windows(width=5,height=7,title="My graph")
plot(data)
par(fig=c(0.05,0.6,0.03,0.6),new=T)
hist(data) # ............................

# parameter mar=c(bottom,left,top,right) ...............................
windows(width=4,height=6,title="My graph")
par(mfrow=c(2,1),mar=c(5,4,3,3))
plot(data)
plot(data)

box(which="figure") # we can see that some space is left for a title ...

# update the parameter for the next figure ...
windows(width=4,height=6,title="My graph")
par(mfrow=c(2,1),mar=c(5,4,2,0.5)) 
plot(data)
par(mar=c(5,4,0.5,0.5)) 
plot(data)

box(which="figure") # ........................

# color of the background ...............
windows(width=4,height=6,title="My graph")
par(bg="black") 
plot(data,col="white") 
box(which="plot",col="white") # .........



###################################
###                             ###
###   ####  #      ###  #####   ###
###   #   # #     #   #   #     ###
###   #   # #     #   #   #     ###
###   ####  #     #   #   #     ###
###   #     #     #   #   #     ###
###   #     #####  ###    #     ###
###                             ###
###################################

plot(data)

# Create a dataset with 50 individuals, 2 groups and 3 variables -----------------------------------------------------#
nb_ind<-50                                                                                                            #
id<-1:nb_ind                                                                                                          #
set.seed(42) ; size_data<-jitter(sort(rnorm(n=nb_ind,mean=175,sd=30)),amount=30)                                      #
set.seed(42) ; mass_data<-jitter(sort(rnorm(n=nb_ind,mean=75,sd=10)),amount=25)                                       #
set.seed(42) ; temp_data<-size_data*mass_data*rnorm(n=nb_ind,mean=100,sd=15)/100000                                   #
group_data<-rep("Group 1",50)                                                                                         #
set.seed(42) ; group_data[sample(1:nb_ind,nb_ind/2,replace=F)]<-"Group 2"                                             #
treatment_data<-rep("Treatment A",50)                                                                                 #
set.seed(55) ; treatment_data[sample(1:nb_ind,nb_ind/2,replace=F)]<-"Treatment B"                                     # 
                                                                                                                      #
data_ms<-data.frame(ID=id,Group=group_data,Treatment=treatment_data,Size=size_data,Mass=mass_data,Temp=temp_data)     #
data_ms[which(data_ms$Treatment=="Treatment A"),"Size"]<-data_ms[which(data_ms$Treatment=="Treatment A"),"Size"]+25   #
data_ms[which(data_ms$Group=="Group 2"),"Mass"]<-data_ms[which(data_ms$Group=="Group 2"),"Mass"]+12                   #
data_ms[which(data_ms$Group=="Group 2"),"Temp"]<-data_ms[which(data_ms$Group=="Group 2"),"Temp"]+10                   #
data_ms[which(data_ms$Treatment=="Treatment A"),"Temp"]<-data_ms[which(data_ms$Treatment=="Treatment A"),"Temp"]+10   #  
# --------------------------------------------------------------------------------------------------------------------#


### BASIC PLOTS ------------------------------------------------------------------------------

# plot() .....................
plot(Mass~Size,data_ms)
plot(Mass~Group,data_ms) # ...

# boxplot() ...............
boxplot(Mass~Group,data_ms)

# stripchart() ...............
stripchart(Mass~Group,data_ms)

# barplot() ..............................................
data_barplot<-aggregate(Mass~Group+Treatment,data_ms,mean)
barplot(data_barplot$Mass) # .............................

# hist() .........
hist(data_ms$Size)

# dotchart() .........
dotchart(data_ms$Mass)

# interaction.plot() ........................................................................
interaction.plot(x.factor=data_ms$Group,trace.factor=data_ms$Treatment,response=data_ms$Mass)

### -----------------------------------------------------------------------------------------



### COMPLEX PLOTS --------------------------------------------

# cdplot() ...........................
cdplot(data_ms$Mass,data_ms$Treatment)

# coplot() ...................................................
coplot(Mass~Size | interaction(Group,Treatment), data=data_ms)

# pairs() ..............................
pairs(data_ms[,c("Mass","Temp","Size")])

# contour() ....
contour(volcano)

# contour() ...........
filled.contour(volcano)

###-------------------------------------------------------------


### CUSTOMIZING A PLOT USING PARAMETERS IN plot() -------------------------------------------------------------

# inside the plotting region ..................................................................................
plot(Size~Temp,data_ms) # default
plot(Size~Temp,data_ms, pch=16) # plotting character
plot(Size~Temp,data_ms, pch=16, cex=2) # character expansion
plot(Size~Temp,data_ms, pch=16, cex=2, col="blue") # color

plot(Size~Temp,data_ms, pch=c(16,23)[Group], cex=2, col="blue") 
plot(Size~Temp,data_ms, pch=c(16,23)[Group], cex=Mass/30, col="blue") 
plot(Size~Temp,data_ms, pch=c(16,23)[Group], cex=Mass/30, col=c("blue","red")[Treatment]) # color - level order



### COLORS ######################################################################################################################################

# 657 built in colors
colors() # but see R color chart

## INDIVIDUAL COLORS ----------------------------------------------------------------------------------------------------------------------------

# R color names .................................................................................
plot(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=c("royalblue1","thistle4")[Treatment])

# Hexadecimal - RGB (#RRGGBB & #RRGGBBAA) .......................................................................
plot(Size~Temp,data_ms, pch=c(16,23)[Group],cex=Mass/30,col=c("#4876FF","#8B7B8B")[Treatment]) # Hexadecimal
plot(Size~Temp,data_ms, pch=c(16,23)[Group],cex=Mass/30,col=c("#4876FF80","#8B7B8B80")[Treatment]) # Transparency

# Adjusting colors transparency easily ........................................................................................
adjustcolor(c("royalblue1","thistle4"),alpha.f=0.5) # here adjusting the alpha factor
plot(Size~Temp,data_ms, pch=c(16,23)[Group],cex=Mass/30,col=adjustcolor(c("royalblue1","thistle4"),alpha.f=0.5)[Treatment]) 
plot(Size~Temp,data_ms, pch=c(16,23)[Group],cex=Mass/30,col=adjustcolor(c("chartreuse4","darkorchid3"),alpha.f=0.5)[Treatment])

## ---------------------------------------------------------------------------------------------------------------------------------------------


## COLOR PALETTES -------------------------------------------------------------------------------------------------

# built-in color palettes
rainbow(5)

# demo plot 
ncolor<-5
plot(1:ncolor,ylim=c(-10,ncolor+10),xlim=c(-10,ncolor+10),col=rainbow(ncolor),cex=4,pch=16)

# Examples in a plot 
plot(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=rainbow(2)[Treatment]) # for Treatments
plot(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=rainbow(max(Temp))[Temp]) # Gradient along Temp
# heat.colors() 
plot(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=heat.colors(max(Temp))[Temp]) # Gradient along Temp
plot(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=heat.colors(max(Temp),rev=T)[Temp]) # reverse
# cm.colors() 
plot(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=cm.colors(max(Temp))[Temp]) # Gradient along Temp
# topo.colors() 
plot(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=topo.colors(max(Temp),rev=T)[Temp]) # Gradient along Temp
# terrain.colors() 
plot(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=terrain.colors(max(Temp))[Temp]) # Gradient along Temp 
filled.contour(volcano,col=terrain.colors(25))

## -----------------------------------------------------------------------------------------------------------------

## COLOR RAMPS with colorRampPalette --------------------------------------------------------

MyPalette<-colorRampPalette(c("red","blue")) 
MyPalette(5)
ncolor<-100
plot(1:ncolor,ylim=c(-10,ncolor+10),xlim=c(-10,ncolor+10),col=MyPalette(ncolor),cex=4,pch=16) 

MyPalette<-colorRampPalette(c("navyblue","cornflowerblue","white","coral","darkred")) 
ncolor<-100
plot(1:ncolor,ylim=c(-10,ncolor+10),xlim=c(-10,ncolor+10),col=MyPalette(ncolor),cex=4,pch=16) 

## ------------------------------------------------------------------------------------------

#######################################################################################################################################################



# the plotting region itself ........................................................................
plot(Size~Temp,data_ms, pch=c(16,23)[Group], cex=Mass/30, col=c("cornflowerblue","coral")[Treatment],
     xlim=c(0,50), ylim=c(0,300)) # .................................................................

# outside the plotting region .................................................................................
plot(Size~Temp,data_ms, pch=c(16,23)[Group], cex=Mass/30, col=c("cornflowerblue","coral")[Treatment],
     xlab="Temperature (°C)", ylab="Size (mm)", cex.lab=1.3, las=1, xaxs="i", yaxs="i", bty="n", family="mono",
     xlim=c(0,50), ylim=c(0,300)) # ...........................................................................




### FONTS #####################################################################################################################

# Load a font from your Font folder (Font Book for mac) - c(normal, bold, italic, bold italic)
windowsFonts(FontComic=c("Comic Sans MS","Comic Sans MS Bold","Comic Sans MS","Comic Sans MS Bold"))
windowsFonts(FontPapyrus=c("Papyrus","Papyrus","Papyrus","Papyrus"))

plot(Size~Temp,data_ms, pch=c(16,23)[Group], cex=Mass/30, col=c("cornflowerblue","coral")[Treatment], # ..............
     xlab="Temperature (°C)", ylab="Size (mm)", cex.lab=1.3, las=1, xaxs="i", yaxs="i", bty="n", family="FontPapyrus",
     xlim=c(0,50), ylim=c(0,300)) # ..................................................................................

plot(Size~Temp,data_ms, pch=c(16,23)[Group], cex=Mass/30, col=c("cornflowerblue","coral")[Treatment], # ........................
     xlab="Temperature (°C)", ylab="Size (mm)", cex.lab=1.3, las=1, xaxs="i", yaxs="i", bty="n", family="FontComic", font.lab=2,
     xlim=c(0,50), ylim=c(0,300)) # ............................................................................................

################################################################################################################################


###############################################
###                                         ###
###    ###  ####      # #####  ###  #####   ###
###   #   # #   #     # #     #   #   #     ###
###   #   # ####      # ####  #       #     ###
###   #   # #   # #   # #     #   #   #     ###
###    ###  ####   ###  #####  ###    #     ###
###                                         ###
###############################################


# locator(x) to get the coordinates of x clicks

# text()
plot(Size~Temp,data_ms, pch=c(16,23)[Group],cex=Mass/30,col=c("cornflowerblue","coral")[Treatment],xlab="Temperature (°C)",ylab="Size (mm)",las=1,xaxs="i",yaxs="i",bty="n",family="sans",xlim=c(0,50), ylim=c(0,300)) 

text(29,149,"Treatment A",col="cornflowerblue",cex=1.5,font=4,adj=0)
text(15,225,"Treatment B",col="coral",cex=1.5,font=4,adj=1)

# mtext ()
plot(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=c("cornflowerblue","coral")[Treatment],xlab="",ylab="Size (mm)",las=1,xaxs="i",yaxs="i",bty="n",family="sans",xlim=c(0,50),ylim=c(0,300)) 
text(c(29,15),c(149,225),c("Treatment A","Treatment B"),col=c("cornflowerblue","coral"),cex=1.5,font=4,pos=c(4,2)) # same thing on a single line

mtext(side=1,line=3,at=25,text="Temperature (°C)",cex=1.5,font=3,family="serif")

# points()
plot(Size~Temp,data_ms,type="n",pch=c(16,23)[Group],cex=Mass/30,col=c("cornflowerblue","coral")[Treatment],xlab="Temperature (°C)",ylab="Size (mm)",las=1,xaxs="i",yaxs="i",bty="n",family="sans",xlim=c(0,50),ylim=c(0,300)) 
points(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=c("cornflowerblue","coral")[Treatment])

# points() to add new information: some stats.
data_mean<-aggregate(cbind(Size,Mass,Temp)~Treatment,data_ms,mean) # Means 
data_stats<-aggregate(cbind(Size,Mass,Temp)~Treatment,data_ms,function(x){cbind(mean(x),sd(x))}) # Means and SDs

# Add a clear hierarchy of the information
plot(Size~Temp,data_ms,type="n",xlab="Temperature (°C)",ylab="Size (mm)",las=1,xaxs="i",yaxs="i",bty="n",family="sans",xlim=c(0,50),ylim=c(0,300)) 
points(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=adjustcolor(c("cornflowerblue","coral"),alpha.f=0.4)[Treatment])
points(Size[,1]~Temp[,1],data_stats,cex=3,pch=25,col=c("dodgerblue","firebrick"),bg=c("dodgerblue","firebrick"))

# segments() to make error bars
with(data_stats,segments(Temp[,1],Size[,1]-Size[,2],Temp[,1],Size[,1]+Size[,2],col=c("dodgerblue","firebrick"),lwd=3,lty="solid"))
with(data_stats,segments(Temp[,1]-Temp[,2],Size[,1],Temp[,1]+Temp[,2],Size[,1],col=c("dodgerblue","firebrick"),lwd=3,lty="solid"))

# segments() to make stars
plot(Size~Temp,data_ms,type="n",xlab="Temperature (°C)",ylab="Size (mm)",las=1,xaxs="i",yaxs="i",bty="n",family="sans",xlim=c(0,50),ylim=c(0,300)) 
text(c(29,15),c(149,225),c("Treatment A","Treatment B"),col=c("cornflowerblue","coral"),cex=1.5,font=4,pos=c(4,2)) # same thing on a single line
segments(data_stats$Temp[1,1],data_stats$Size[1,1],subset(data_ms,Treatment=="Treatment A")$Temp,subset(data_ms,Treatment=="Treatment A")$Size,col=adjustcolor("cornflowerblue",0.5))
segments(data_stats$Temp[2,1],data_stats$Size[2,1],subset(data_ms,Treatment=="Treatment B")$Temp,subset(data_ms,Treatment=="Treatment B")$Size,col=adjustcolor("coral",0.5))
points(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col="white",bg="white")
points(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=adjustcolor(c("cornflowerblue","coral"),alpha.f=0.8)[Treatment],bg=adjustcolor(c("cornflowerblue","coral"),alpha.f=0.4)[Treatment])

# abline() to add straight lines
plot(Size~Temp,data_ms,type="n",xlab="Temperature (°C)",ylab="Size (mm)",las=1,xaxs="i",yaxs="i",bty="n",family="sans",xlim=c(0,50),ylim=c(0,300)) 
abline(h=mean(data_ms$Size),v=mean(data_ms$Temp),lty="dotted",col="lightgrey",lwd=1.5)

### LINE TYPE - LTY ############################################################################################################################################################################
plot(Size~Temp,data_ms,type="n",xlab="Temperature (°C)",ylab="Size (mm)",las=1,xaxs="i",yaxs="i",bty="n",family="sans",xlim=c(0,50),ylim=c(0,300)) 
abline(h=mean(data_ms$Size),v=mean(data_ms$Temp),lty="13",col="lightgrey",lwd=1.5)

text(c(29,15),c(149,225),c("Treatment A","Treatment B"),col=c("cornflowerblue","coral"),cex=1.5,font=4,pos=c(4,2)) # same thing on a single line
segments(data_stats$Temp[1,1],data_stats$Size[1,1],subset(data_ms,Treatment=="Treatment A")$Temp,subset(data_ms,Treatment=="Treatment A")$Size,col=adjustcolor("cornflowerblue",0.5))
segments(data_stats$Temp[2,1],data_stats$Size[2,1],subset(data_ms,Treatment=="Treatment B")$Temp,subset(data_ms,Treatment=="Treatment B")$Size,col=adjustcolor("coral",0.5))
points(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col="white",bg="white")
points(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=adjustcolor(c("cornflowerblue","coral"),alpha.f=0.8)[Treatment],bg=adjustcolor(c("cornflowerblue","coral"),alpha.f=0.4)[Treatment])
################################################################################################################################################################################################

# lines() to add a curve
set.seed(42) ; hist(rnorm(1:50,mean=75,sd=10),col=adjustcolor("skyblue",0.5),border="white",xlim=c(20,120),xlab="Mass (mg)",main="Mass",las=1,ylim=c(0,0.04),freq=F)
x_grp1<-seq(35,110,length=1000)
y_grp1<-dnorm(x_grp1,mean=75,sd=10)
lines(x_grp1,y_grp1,col="salmon",lwd=2)

# arrows() to add error bars
plot(Size~Temp,data_ms,type="n",xlab="Temperature (°C)",ylab="Size (mm)",las=1,xaxs="i",yaxs="i",bty="n",family="sans",xlim=c(0,50),ylim=c(0,300)) 
points(Size~Temp,data_ms,pch=c(16,23)[Group],cex=Mass/30,col=adjustcolor(c("cornflowerblue","coral"),alpha.f=0.4)[Treatment])
points(Size[,1]~Temp[,1],data_stats,cex=3,pch=25,col=c("dodgerblue","firebrick"),bg=c("dodgerblue","firebrick"))

with(data_stats,arrows(Temp[,1],Size[,1]-Size[,2],Temp[,1],Size[,1]+Size[,2],col=c("dodgerblue","firebrick"),lwd=3,lty="solid",code=3,length=0.05,angle=90))
with(data_stats,arrows(Temp[,1]-Temp[,2],Size[,1],Temp[,1]+Temp[,2],Size[,1],col=c("dodgerblue","firebrick"),lwd=3,lty="solid",code=3,length=0.05,angle=90))

# polygon() for a distribution
set.seed(42) ; hist(rnorm(1:50,mean=75,sd=10),col=adjustcolor("skyblue",0.5),border="white",xlim=c(20,160),xlab="Mass (mg)",main="Mass",las=1,ylim=c(0,0.05),freq=F,nclass=6)
x_grp1<-seq(35,110,length=1000)
y_grp1<-dnorm(x_grp1,mean=75,sd=10)
lines(x_grp1,y_grp1,col="dodgerblue",lwd=2)

set.seed(55) ; hist(rnorm(1:50,mean=95,sd=20),col=adjustcolor("chartreuse3",0.5),border="white",add=T,freq=F,nclass=12)
x_grp2<-seq(20,160,length=1000)
y_grp2<-dnorm(x_grp2,mean=95,sd=20)
lines(x_grp2, y_grp2,col="limegreen",lwd=2)

plot(1,1,type="n",xlim=c(20,160),ylim=c(0,0.05),xlab="Mass (mg)",ylab="Frequency",main="Mass histogram",bty="n")
polygon(x_grp1,y_grp1,col=adjustcolor("chartreuse3",0.5),lwd=2)
polygon(x_grp2,y_grp2,col=adjustcolor("skyblue",0.5),lwd=2)

# polygon() for an error ribbon 
data_ord<-data_ms[order(data_ms$Temp),]
lo<-predict(loess(Size~Temp,data_ord),se=T)
error<-qt(0.975,lo$df)*lo$se
upper<-lo$fit + error
lower<-lo$fit - error

plot(Size~Temp,data_ord,type="n",xlab="Temperature (°C)",ylab="Size (mm)",las=1,xaxs="i",yaxs="i",bty="n",family="sans",xlim=c(0,50),ylim=c(0,350)) 
polygon(c(data_ord$Temp,rev(data_ord$Temp)),c(upper,rev(lower)),border="transparent",col=adjustcolor("orchid",0.5))
lines(data_ord$Temp,lo$fit,col="darkorchid",lwd=2)
points(Size~Temp,data_ord,col="darkorchid",pch=21,cex=0.7,bg="white")


# panel.smooth() to add loess lines to complex plots
pairs(data_ms[,c("Mass","Temp","Size")],panel=panel.smooth)


windows(height=5,width=6)
par(mar=c(5,4,2,2))
plot(Size~Temp,data_ord,xaxt="n",yaxt="n",type="n",xlab="Temperature (°C)",ylab="Size (mm)",las=1,xaxs="i",yaxs="i",bty="n",family="sans",xlim=c(0,50),ylim=c(50,350)) 

# rect() to draw a rectangle
rect(0,50,50,350,border="transparent",col="grey90")

# axis() to manipulate axes
axis(side=1,tick=F,line=F)
axis(side=2,at=seq(50,350,by=100),labels=seq(50,350,by=100),tick=F,line=F,las=1)

# grid() to add a background grid
grid(5,3,col="white")

# box() to add an outline to the plot or the figure
box("plot",lwd=2)
polygon(c(data_ord$Temp,rev(data_ord$Temp)),c(upper,rev(lower)),border="transparent",col="white")
polygon(c(data_ord$Temp,rev(data_ord$Temp)),c(upper,rev(lower)),border="transparent",col=adjustcolor("orchid",0.5))
lines(data_ord$Temp,lo$fit,col="darkorchid",lwd=2)
points(Size~Temp,data_ord,col="darkorchid",pch=21,cex=0.7,bg="white")
mtext(text="Relationship between Size and Temperature",line=-1.8,cex=1.3,font=2,family="serif")






########################################
###                                  ###
###   ##### #  # ##### ####   ###    ###
###   #     #  #   #   #   # #   #   ###
###   ####   ##    #   ####  #####   ###
###   #     #  #   #   #  #  #   #   ###
###   ##### #  #   #   #   # #   #   ###
###                                  ###
########################################




# PLOT

windows(height=7,width=11)
layout(mat=matrix(c(1,3,3,2,3,3),nrow=2,ncol=3,byrow=T))
par(ylbias=-0.3,mar=c(6,5,4,2)) # MARgins

for (loop_species in 1:nlevels(iris$Species))
{
	Sub_sp<-levels(iris$Species)[loop_species]
	sub_data<-subset(iris,Species==levels(iris$Species)[loop_species])
	
	plot(Sepal.Length~Sepal.Width,data=droplevels(subset(iris,Species!=Sub_sp)),
	     xlim=c(1.8,5),ylim=c(4,8),
	     pch=16,
	     col=alpha(c("lightgrey","lightgrey")[Species],0.5),
	     cex=Petal.Length,
	     bty="n",
	     las=1, 
	     xlab="Sepal width (cm)",ylab="Sepal length (cm)",
	     main=c("Iris setosa","Iris versicolor","Iris virginica")[loop_species],
	     col.main=alpha(c("coral","cornflowerblue","darkorchid")[loop_species],0.5),
	     cex.main=3,
	     font.main=4,
	     axes=FALSE,
	     cex.lab=2, 
	     font.lab=2,
	     col.lab="grey30")
	points(Sepal.Length~Sepal.Width,data=subset(iris,Species==Sub_sp),
	       col=alpha(c("coral","cornflowerblue","darkorchid")[loop_species],0.5),
	       pch=16,
	       cex=Petal.Length)
	axis(side=1,col="grey30",lwd=3,font=2,las=1,at=c(2:5),cex.axis=2,col.axis="grey30")
	axis(side=2,col="grey30",lwd=3,font=2,las=1,at=c(4:8),cex.axis=2,col.axis="grey30")

	linear_model<-lm(Sepal.Length~Sepal.Width,data=sub_data)
	segments(min(sub_data$Sepal.Width), # x1
	         min(sub_data$Sepal.Width)*linear_model$coeff[2]+linear_model$coeff[1], # y1
	         max(sub_data$Sepal.Width), # x2
	         max(sub_data$Sepal.Width)*linear_model$coeff[2]+linear_model$coeff[1], # y2
	         col=c("red","blue","magenta")[loop_species],lwd=3)
}






# BOXPLOT

windows(height=7,width=7)
boxplot(Sepal.Length ~ Species, data=iris,
        las=1,
        boxwex=0.5,
        notch=TRUE,
        col=alpha(c("coral","cornflowerblue","darkorchid"),0.5),
        border="grey40",
        ylab="Sepal length")






# BARPLOT

data_barplot<-as.matrix(aggregate(cbind(Petal.Length,Petal.Width,Sepal.Length,Sepal.Width) ~ Species , data=iris , FUN=mean)[,2:5])
rownames(data_barplot)<-levels(iris$Species)

windows(height=7,width=9)
barplot(data_barplot,
		beside=T, # puts the bars side by side instead of on top of each other - you can write T instead of TRUE (and F instead of FALSE)
		legend=T, # adds a legend
		col=c("coral","cornflowerblue","darkorchid"), # the colors filling the bars
		border="transparent", # the color of the border of the bars
		las=1, # orientation of the ticks labels
		ylab="size (cm)", # Y-axis LABel
		names=c("Petal length","Petal width","Sepal length","Sepal width"), # X-axis labels for the groups of bars (single bar if beside=FALSE)
        cex.names=1.3)
        
      
      
      
      
      
# BARPLOT WITHOUT BARPLOT()

HIT<-data.frame(Food=c("A","B","C","AB","AC"),Mean=c(0.50,0.40,0.20,0.75,0.55),SEM=c(0.08,0.1,0.05,0.12,0.09))
REC<-data.frame(Food=c("A","B","C","BC","AC"),Mean=c(70,30,34,12,63),SEM=c(3,9,9,7,5))

windows(height=6,width=10)
par(mfrow=c(1,2),xpd=T,lwd=1)
# HITS - VIALS DISCOVERED
plot(1,1,type="n",ylim=c(0,1),xlim=c(0,7),las=1,lwd=1,bty="n",xaxt="n",yaxt="n",ylab="",xlab="")
segments(0,seq(0,1,0.2),6,seq(0,1,0.2),col="lightgrey")
rect(0,-0.1,6,1.05,lwd=2) # outside box
rect(1:5-0.4,0,1:5+0.4,HIT$Mean,col="white",border="transparent") # white bars to hide the grey lines
rect(1:5-0.4,0,1:5+0.4,HIT$Mean,col=alpha(c("cornflowerblue","firebrick3","goldenrod2","cornflowerblue","firebrick3"),0.7),border="transparent") # bars
par(lwd=5,lend="butt") ; rect(4:5-0.4,0,4:5+0.4,HIT$Mean[4:5],col=alpha("goldenrod2",0.7),density=9,border="transparent") # bars
par(lwd=3) ; rect(1:5-0.4,0,1:5+0.4,HIT$Mean,col="transparent",border="white") # bars
par(lwd=2) ; rect(1:5-0.4,0,1:5+0.4,HIT$Mean,border="black") # bars
par(lwd=2,lend="round")
arrows(1:5,HIT$Mean+HIT$SEM,1:5,HIT$Mean,code=1,length=0.05,angle=90,lwd=2,col="black")
mtext(at=1:5,line=-0.26,side=1,font=2,text=c("A","B","C","AC","BC"),cex=1.2,col="black")
mtext(at=seq(0,1,0.2),side=2,las=1,text=as.character(seq(0,100,20)),line=0,cex=1.1,font=2)
mtext(at=0.5,side=2,text="% Vials Discovered",line=2,cex=1.4,font=2)
text(1:5,HIT$Mean+HIT$SEM+0.05,c("a","a","b","c","ac"),cex=1.2,font=2)
text(0.75,0.95,"A",cex=4,font=2)
# RECRUIT - ANTS RECRUITED PER VIAL
par(lwd=1)
plot(1,1,type="n",ylim=c(0,100),xlim=c(0,7),las=1,lwd=1,bty="n",xaxt="n",yaxt="n",ylab="",xlab="")
segments(0,seq(0,100,20),6,seq(0,100,20),col="lightgrey")
rect(0,-10,6,105,lwd=2) # outside box
rect(1:5-0.4,0,1:5+0.4,REC$Mean,col="white",border="transparent") # white bars to hide the grey lines
rect(1:5-0.4,0,1:5+0.4,REC$Mean,col=alpha(c("cornflowerblue","firebrick3","goldenrod2","cornflowerblue","firebrick3"),0.7),border="transparent") # bars
par(lwd=5,lend="butt") ; rect(4:5-0.4,0,4:5+0.4,REC$Mean[4:5],col=alpha("goldenrod2",0.7),density=9,border="transparent") # bars
par(lwd=3) ; rect(1:5-0.4,0,1:5+0.4,REC$Mean,col="transparent",border="white") # bars
par(lwd=2) ; rect(1:5-0.4,0,1:5+0.4,REC$Mean,border="black") # bars
par(lwd=2,lend="round")
arrows(1:5,REC$Mean+REC$SEM,1:5,REC$Mean,code=1,length=0.05,angle=90,lwd=2,col="black")
mtext(at=1:5,line=-0.26,side=1,font=2,text=c("A","B","C","AC","BC"),cex=1.2,col="black")
mtext(at=seq(0,100,20),side=2,las=1,text=as.character(seq(0,100,20)),line=0,cex=1.1,font=2)
mtext(at=50,side=2,text="Ants recruited per vial",line=2,cex=1.4,font=2)
text(1:5,REC$Mean+REC$SEM+5,c("a","b","b","c","a"),cex=1.2,font=2)
text(0.75,95,"B",cex=4,font=2)







        
        
        
